| Title: | Scrape Deutsche Turnliga Archive |
|---|---|
| Description: | Provides helper functions to scrape the online archive of the Deutsche Turnliga <https://www.deutsche-turnliga.de/archiv.html>. Also included is data of one competition and one matchday as test data. |
| Authors: | Julian Grimm [aut, cre] |
| Maintainer: | Julian Grimm <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-05-28 06:33:30 UTC |
| Source: | https://github.com/grimmjulian/dtlscores |
A dataset containing the result of the competition between Eintracht Frankfurt and TuS Vinnhorst from the 12.04.2025. The competition took place in the 2025 season of the 1. Bundesliga on the first matchday.
competitioncompetition
A data frame with 15 columns and 24 rows:
Name of the home team
Name of the guest team
Event of the pairing
Order of pairings per event
Name of gymnast of home team
URL to profile of gymnast of home team
Logical value if the home team started the pairing
D-value of the home gymnast
End value of the home gymnast
Scraped score result of the home gymnast
Name of gymnast of guest team
URL to profile of gymnast of guest team
D-value of the guest gymnast
End value of the guest gymnast
Scraped score result of the guest gymnast
https://www.deutsche-turnliga.de/dtl/historie/archiv/detailsm0.html?ID=2764
A dataset containing the data of the first matchday of the 2025 season of the 1. Bundesliga.
matchdaymatchday
A data frame with 3 columns and 4 rows:
type_id of the matchday
type of the matchday
season_id of the matchday
season of the matchday
league_id of the matchday
league of the matchday
matchday_id of the matchday
matchday label of the matchday
Date and time of the competition as POSIXct
Address of competition stadium
Title of competition; generally the two teams
URL to competition page
Official final score result of competition
Official final gp result of competition
https://www.deutsche-turnliga.de/archiv.html?Typ=Mann&SaisonID=20&LigaID=760&TagesID=666
This data set contains urls to all match days in currently parseable leagues.
matchday_urlsmatchday_urls
A data frame with 5 columns and 519 rows:
type of the matchday
season of the matchday
league of the matchday
matchday label of the matchday
url to matchday
Parse or scrape results from the competition site
parse_competition(url)parse_competition(url)
url |
page url |
data.frame
parse_competition("https://www.deutsche-turnliga.de/dtl/historie/archiv/detailsm0.html?ID=2787")parse_competition("https://www.deutsche-turnliga.de/dtl/historie/archiv/detailsm0.html?ID=2787")
Parse or scrape the meta data of a matchday from a matchday overview page.
parse_matchday(url)parse_matchday(url)
url |
page url |
data.frame
parse_matchday("https://www.deutsche-turnliga.de/archiv.html")parse_matchday("https://www.deutsche-turnliga.de/archiv.html")