| Title: | Scrape Deutsche Turnliga Archive |
| Version: | 0.1.0 |
| Description: | Provides helper functions to scrape the online archive of the Deutsche Turnliga https://www.deutsche-turnliga.de/archiv.html. Also included is data of one competition and one matchday as test data. |
| License: | MIT + file LICENSE |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.3 |
| Imports: | rvest |
| Suggests: | testthat (≥ 3.0.0) |
| Config/testthat/edition: | 3 |
| Depends: | R (≥ 4.1.0) |
| LazyData: | true |
| NeedsCompilation: | no |
| Packaged: | 2026-03-18 10:11:42 UTC; julian |
| Author: | Julian Grimm [aut, cre] |
| Maintainer: | Julian Grimm <grimmjulian225@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-03-23 09:30:02 UTC |
Example dataset of competition
Description
A dataset containing the result of the competition between Eintracht Frankfurt and TuS Vinnhorst from the 12.04.2025. The competition took place in the 2025 season of the 1. Bundesliga on the first matchday.
Usage
competition
Format
A data frame with 15 columns and 24 rows:
- home_team
Name of the home team
- guest_team
Name of the guest team
- event
Event of the pairing
- pairing_order
Order of pairings per event
- home_gymnast
Name of gymnast of home team
- home_gymnast_url
URL to profile of gymnast of home team
- home_starts
Logical value if the home team started the pairing
- home_d_value
D-value of the home gymnast
- home_end_value
End value of the home gymnast
- home_score_value
Scraped score result of the home gymnast
- guest_gymnast
Name of gymnast of guest team
- guest_gymnast_url
URL to profile of gymnast of guest team
- guest_d_value
D-value of the guest gymnast
- guest_end_value
End value of the guest gymnast
- guest_score_value
Scraped score result of the guest gymnast
https://www.deutsche-turnliga.de/dtl/historie/archiv/detailsm0.html?ID=2764
Example dataset of a matchday
Description
A dataset containing the data of the first matchday of the 2025 season of the 1. Bundesliga.
Usage
matchday
Format
A data frame with 3 columns and 4 rows:
- type_id
type_id of the matchday
- type
type of the matchday
- season_id
season_id of the matchday
- season
season of the matchday
- league_id
league_id of the matchday
- league
league of the matchday
- matchday_id
matchday_id of the matchday
- matchday
matchday label of the matchday
- datetime
Date and time of the competition as POSIXct
- location
Address of competition stadium
- title
Title of competition; generally the two teams
- competition_url
URL to competition page
- score
Official final score result of competition
- gp
Official final gp result of competition
https://www.deutsche-turnliga.de/archiv.html?Typ=Mann&SaisonID=20&LigaID=760&TagesID=666
Parse competition results
Description
Parse or scrape results from the competition site
Usage
parse_competition(url)
Arguments
url |
page url |
Value
data.frame
Examples
parse_competition("https://www.deutsche-turnliga.de/dtl/historie/archiv/detailsm0.html?ID=2787")
Parse matchday data Parse or scrape the meta data of a matchday from a matchday overview page.
Description
Parse matchday data Parse or scrape the meta data of a matchday from a matchday overview page.
Usage
parse_matchday(url)
Arguments
url |
page url |
Value
data.frame
Examples
parse_matchday("https://www.deutsche-turnliga.de/archiv.html")